# TESTSKRIPT;TARGET
# regular usage;# regular usage
irisdt <- as.data.table(iris)
irisdt <- data.table::as.data.table(iris)
carsdt <- data.table::as.data.table(cars)
carsdt <- data.table::as.data.table(cars)
carsdt <- merge.data.table(cars)
carsdt <- data.table::merge.data.table(cars)

eqn <- "
\\begin{equation*}
\\overset
  \\end{pmatrix}}
"
script <- readLines("inst/testdata/test_script.R")
